@@ -54,7 +54,7 @@ impl Graphics<'_>
 
     pub fn draw_line(&mut self, position_start: [f32; 2], position_end: [f32; 2], width: f32, color: [u8; 4])
     {
-        let line_rect = rectangle::rectangle_by_corners(position_start[0].min(position_end[0]).into(), position_start[1].min(position_end[1]).into(), position_start[0].max(position_end[0]).into(), position_start[1].max(position_end[1]).into());
+        let line_rect = rectangle::rectangle_by_corners(position_start[0].into(), position_start[1].into(), position_end[0].into(), position_end[1].into());
         line(translate_color(color), (width / 2.0).into(), line_rect, self.c.transform, self.gl);
     }
 
